@@ -1,6 +1,6 @@
 package WWW::Google::CustomSearch::Page;
 
-$WWW::Google::CustomSearch::Page::VERSION   = '0.25';
+$WWW::Google::CustomSearch::Page::VERSION   = '0.26';
 $WWW::Google::CustomSearch::Page::AUTHORITY = 'cpan:MANWAR';
 
 =head1 NAME
@@ -9,7 +9,7 @@ WWW::Google::CustomSearch::Page - Placeholder for Google JSON/Atom Custom Search
 
 =head1 VERSION
 
-Version 0.25
+Version 0.26
 
 =cut
 
@@ -156,12 +156,12 @@ object.
     use strict; use warnings;
     use WWW::Google::CustomSearch;
 
-    my $api_key = 'Your_API_Key';
-    my $cx      = 'Search_Engine_Identifier';
-    my $engine  = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
-    my $result  = $engine->search("Google");
-    my $page    = $result->nextPage;
-    my $next    = $page->fetch;
+    my $api_key    = 'Your_API_Key';
+    my $cx         = 'Search_Engine_Identifier';
+    my $engine     = WWW::Google::CustomSearch->new(api_key => $api_key, cx => $cx);
+    my $result     = $engine->search("Google");
+    my $page       = $result->nextPage;
+    my $nextResult = $page->fetch;
 
 =cut
 
@@ -223,8 +223,8 @@ L<http://search.cpan.org/dist/WWW-Google-CustomSearch/>
 
 Copyright (C) 2011 - 2015 Mohammad S Anwar.
 
-This  program  is  free software; you can redistribute it and/or modify it under
-the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
+This program  is  free software; you can redistribute it and / or modify it under
+the  terms  of the the Artistic License (2.0). You may obtain  a copy of the full
 license at:
 
 L<http://www.perlfoundation.org/artistic_license_2_0>
